"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const cheerio = require("cheerio");
const fs = require("fs");
const mkdirp = require("mkdirp");
const path = require("path");
const puppeteer = require("puppeteer");
var Statisfy;
(function (Statisfy) {
    function generateStaticHtml(config) {
        const puppeteerArgs = [];
        if (config.sandBox === false) {
            puppeteerArgs.push(...[
                '--no-sandbox',
                '--disable-setuid-sandbox',
            ]);
        }
        (() => __awaiter(this, void 0, void 0, function* () {
            const browser = yield puppeteer.launch({ args: puppeteerArgs });
            for (const route of config.routes) {
                const fullRoute = config.host + route;
                console.log(`Statisfying ${fullRoute}`);
                let html;
                let success = false;
                let tryCounter = 0;
                while (!success && tryCounter <= 3) {
                    try {
                        const page = yield browser.newPage();
                        yield page.goto(fullRoute);
                        html = yield page.evaluate(() => document.documentElement.outerHTML);
                        yield page.close();
                        success = true;
                    }
                    catch (e) {
                        console.warn(`Could not evaluate ${fullRoute} in`
                            + ` try ${tryCounter++}.`);
                        console.warn(`Error: ${e}`);
                    }
                }
                if (!success) {
                    console.error(`Could not evaluate ${fullRoute} in ${tryCounter} tries.`);
                    continue;
                }
                const dom = cheerio.load(html);
                dom('script').each((index, item) => {
                    if ('src' in item.attribs && !item.attribs.src.startsWith('http')) {
                        dom(item).remove();
                    }
                });
                dom('base').attr('href', config.host);
                const editedDom = dom.html();
                writeFile(`${config.directory}/${route ? route : 'index'}.html`, editedDom, err => {
                    if (err) {
                        console.log(err);
                        process.exit(1);
                    }
                });
            }
            yield browser.close();
        }))();
    }
    Statisfy.generateStaticHtml = generateStaticHtml;
    function writeFile(filePath, contents, cb) {
        mkdirp(path.dirname(filePath), err => {
            if (err) {
                return cb(err);
            }
            fs.writeFile(filePath, contents, cb);
        });
    }
})(Statisfy = exports.Statisfy || (exports.Statisfy = {}));
//# sourceMappingURL=build-static.js.map